# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "freeradius",
        "version": "2.1.8",
        "version_strings": ["FreeRADIUS Version 2.1.8"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/freeradius/3.0.8/2.fc23/x86_64/",
        "package_name": "freeradius-3.0.8-2.fc23.x86_64.rpm",
        "product": "freeradius",
        "version": "3.0.8",
    },
    {
        "url": "http://rpmfind.net/linux/mageia/distrib/5/x86_64/media/core/updates/",
        "package_name": "freeradius-2.2.10-1.mga5.x86_64.rpm",
        "product": "freeradius",
        "version": "2.2.10",
    },
    {
        "url": "https://ftp.netbsd.org/pub/pkgsrc/packages/NetBSD/aarch64/9.1/All/",
        "package_name": "freeradius-3.0.21nb3.tgz",
        "product": "freeradius",
        "version": "3.0.21",
    },
    {
        "url": "http://ftp.br.debian.org/debian/pool/main/f/freeradius/",
        "package_name": "freeradius_3.0.12+dfsg-5+deb9u1_amd64.deb",
        "product": "freeradius",
        "version": "3.0.12",
    },
]
